==> bootstrap-7.0.2.tgz: package/tsDist/components/dashboard/shared/Statistic/presenters/styles.js <==
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
import styled from 'styled-components';
import ContentLoader from 'react-content-loader';
import defaultTheme from 'theme';
import { InfoCircle } from 'components/icons';
import { Box } from 'components/elements/Flex';
export var Header = styled.div(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  width: 100%;\n  display: flex;\n  justify-content: space-between;\n  flex-wrap: wrap;\n  align-items: center;\n"], ["\n  width: 100%;\n  display: flex;\n  justify-content: space-between;\n  flex-wrap: wrap;\n  align-items: center;\n"])));
export var WidgetTitle = styled.span(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n  font-size: 18px;\n  font-weight: bold;\n  line-height: 35px;\n  color: ", ";\n"], ["\n  font-size: 18px;\n  font-weight: bold;\n  line-height: 35px;\n  color: ", ";\n"])), function (_a) {
    var theme = _a.theme;
    return theme.colors.primaryText.default;
});
export var TitleText = styled.div(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n  color: ", ";\n  font-size: 16px;\n  width: 100%;\n  text-align: center;\n  padding-top: 20px;\n  padding-bottom: 10px;\n  font-weight: 600;\n"], ["\n  color: ", ";\n  font-size: 16px;\n  width: 100%;\n  text-align: center;\n  padding-top: 20px;\n  padding-bottom: 10px;\n  font-weight: 600;\n"])), function (_a) {
    var theme = _a.theme;
    return theme.colors.secondaryText.default;
});
export var StatisticsContainer = styled.div(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n  display: flex;\n  flex-direction: row;\n  justify-content: space-around;\n  flex-wrap: wrap;\n  width: 100%;\n"], ["\n  display: flex;\n  flex-direction: row;\n  justify-content: space-around;\n  flex-wrap: wrap;\n  width: 100%;\n"])));
export var StatisticsColumn = styled.div(templateObject_5 || (templateObject_5 = __makeTemplateObject(["\n  display: block;\n  text-align: center;\n  width: 33.3%;\n  min-width: 180px;\n"], ["\n  display: block;\n  text-align: center;\n  width: 33.3%;\n  min-width: 180px;\n"])));
export var DiffText = styled.div(templateObject_6 || (templateObject_6 = __makeTemplateObject(["\n  color: ", ";\n  font-size: 12px;\n  line-height: 1em;\n  width: 100%;\n  text-align: center;\n  padding-top: 10px;\n"], ["\n  color: ", ";\n  font-size: 12px;\n  line-height: 1em;\n  width: 100%;\n  text-align: center;\n  padding-top: 10px;\n"])), function (_a) {
    var theme = _a.theme;
    return theme.colors.secondaryText.default;
});
export var InfoIcon = styled(InfoCircle)(function (_a) {
    var theme = _a.theme;
    return ({
        fill: theme.colors.secondaryText.default,
    });
}, {
    width: 12,
    height: 12,
    marginLeft: 4,
    marginBottom: 6,
});
export var InfoBody = styled.div({
    fontSize: 10,
    width: '100%',
    textAlign: 'left',
});
export var StatisticBox = styled(Box).attrs({
    height: '21em',
    centered: true,
})(function (_a) {
    var theme = _a.theme;
    return ({
        borderRadius: theme.sizes.borderRadius,
        flexWrap: 'nowrap',
    });
});
StatisticBox.defaultProps = {
    theme: defaultTheme,
};
export var StyledContentLoader = styled(ContentLoader)(templateObject_7 || (templateObject_7 = __makeTemplateObject(["\n  width: 200px;\n  height: 272px;\n"], ["\n  width: 200px;\n  height: 272px;\n"])));
export var ControlWrapper = styled.div(templateObject_8 || (templateObject_8 = __makeTemplateObject(["\n  display: flex;\n  align-items: center;\n"], ["\n  display: flex;\n  align-items: center;\n"])));
export var ChartWrapper = styled.div(templateObject_9 || (templateObject_9 = __makeTemplateObject(["\n  height: 100%;\n  width: 100%;\n  margin-bottom: 30px;\n"], ["\n  height: 100%;\n  width: 100%;\n  margin-bottom: 30px;\n"])));
export var GoBackButton = styled.button(function (_a) {
    var theme = _a.theme;
    var color = theme.colors.secondaryText.default;
    return {
        borderRadius: '50%',
        padding: 0,
        width: '34px',
        height: '34px',
        display: 'flex',
        justifyContent: 'center',
        alignItems: 'center',
        background: '#fff',
        color: color,
        border: "1px solid " + color,
        transition: '0.2s',
        marginRight: '1em',
        '&:hover': {
            color: '#fff',
            background: color,
        },
    };
});
var templateObject_1, templateObject_2, templateObject_3, templateObject_4, templateObject_5, templateObject_6, templateObject_7, templateObject_8, templateObject_9;

==> bootstrap-7.0.19.tgz: package/tsDist/components/dashboard/shared/Statistic/presenters/styles.js <==
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
import styled from 'styled-components';
import ContentLoader from 'react-content-loader';
import defaultTheme from 'theme';
import { InfoCircle } from 'components/icons';
import { Box } from 'components/elements/Flex';
export var Header = styled.div(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  width: 100%;\n  display: flex;\n  justify-content: space-between;\n  flex-wrap: wrap;\n  align-items: center;\n"], ["\n  width: 100%;\n  display: flex;\n  justify-content: space-between;\n  flex-wrap: wrap;\n  align-items: center;\n"])));
export var WidgetTitle = styled.span(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n  font-size: 18px;\n  font-weight: bold;\n  line-height: 35px;\n  color: ", ";\n"], ["\n  font-size: 18px;\n  font-weight: bold;\n  line-height: 35px;\n  color: ", ";\n"])), function (_a) {
    var theme = _a.theme;
    return theme.colors.primaryText.default;
});
export var TitleText = styled.div(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n  color: ", ";\n  font-size: 16px;\n  width: 100%;\n  text-align: center;\n  padding-top: 20px;\n  padding-bottom: 20px;\n  font-weight: 600;\n"], ["\n  color: ", ";\n  font-size: 16px;\n  width: 100%;\n  text-align: center;\n  padding-top: 20px;\n  padding-bottom: 20px;\n  font-weight: 600;\n"])), function (_a) {
    var theme = _a.theme;
    return theme.colors.secondaryText.default;
});
export var StatisticsContainer = styled.div(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n  display: flex;\n  flex-direction: row;\n  justify-content: space-around;\n  flex-wrap: wrap;\n  width: 100%;\n  padding-bottom: 40px;\n"], ["\n  display: flex;\n  flex-direction: row;\n  justify-content: space-around;\n  flex-wrap: wrap;\n  width: 100%;\n  padding-bottom: 40px;\n"])));
export var StatisticsColumn = styled.div(templateObject_5 || (templateObject_5 = __makeTemplateObject(["\n  display: block;\n  text-align: center;\n  width: 33.3%;\n  min-width: 180px;\n"], ["\n  display: block;\n  text-align: center;\n  width: 33.3%;\n  min-width: 180px;\n"])));
export var DiffText = styled.div(templateObject_6 || (templateObject_6 = __makeTemplateObject(["\n  color: ", ";\n  font-size: 14px;\n  width: 100%;\n  text-align: center;\n  padding-top: 20px;\n"], ["\n  color: ", ";\n  font-size: 14px;\n  width: 100%;\n  text-align: center;\n  padding-top: 20px;\n"])), function (_a) {
    var theme = _a.theme;
    return theme.colors.secondaryText.default;
});
export var InfoIcon = styled(InfoCircle)(function (_a) {
    var theme = _a.theme;
    return ({
        fill: theme.colors.secondaryText.default,
    });
}, {
    width: 12,
    height: 12,
    marginLeft: 4,
    marginBottom: 6,
});
export var InfoBody = styled.div({
    width: '100%',
    textAlign: 'left',
});
export var StatisticBox = styled(Box).attrs({
    centered: true,
    verticalAlign: 'center',
})(function (_a) {
    var theme = _a.theme;
    return ({
        borderRadius: theme.sizes.borderRadius,
        flexWrap: 'nowrap',
    });
});
StatisticBox.defaultProps = {
    theme: defaultTheme,
};
export var StyledContentLoader = styled(ContentLoader)(templateObject_7 || (templateObject_7 = __makeTemplateObject(["\n  width: 200px;\n  height: 272px;\n"], ["\n  width: 200px;\n  height: 272px;\n"])));
export var ControlWrapper = styled.div(templateObject_8 || (templateObject_8 = __makeTemplateObject(["\n  display: flex;\n  align-items: center;\n"], ["\n  display: flex;\n  align-items: center;\n"])));
export var ChartWrapper = styled.div(templateObject_9 || (templateObject_9 = __makeTemplateObject(["\n  height: 100%;\n  width: 100%;\n  margin-bottom: 30px;\n"], ["\n  height: 100%;\n  width: 100%;\n  margin-bottom: 30px;\n"])));
export var GoBackButton = styled.button(function (_a) {
    var theme = _a.theme;
    var color = theme.colors.secondaryText.default;
    return {
        borderRadius: '50%',
        padding: 0,
        width: '34px',
        height: '34px',
        display: 'flex',
        justifyContent: 'center',
        alignItems: 'center',
        background: '#fff',
        color: color,
        border: "1px solid " + color,
        transition: '0.2s',
        marginRight: '1em',
        '&:hover': {
            color: '#fff',
            background: color,
        },
    };
});
var templateObject_1, templateObject_2, templateObject_3, templateObject_4, templateObject_5, templateObject_6, templateObject_7, templateObject_8, templateObject_9;
